<!--
 * @Author: elkers
 * @Date: 2024-08-06 16:17:39
 * @LastEditors: Liuyi candymxq888@outlook.com
 * @LastEditTime: 2024-09-28 10:36:18
 * @FilePath: \water-qinghe-web\src\views\alarm\alarmHistory\index.vue
 * @Description: 历史记录
-->

<script setup>
import alarmSchemeApi from "@/api/alarmApi/alarmScheme.js";
import facilityApi from "@/api/facility/index";
import waterFacilityParameter from "@/api/configuration/facilityParameter/index.js";
import {ref} from "vue";
import user from "@/api/system/user.js";
import waterMeterApi from "@/api/waterMeterApi/index.js";
import {sysDictData} from "@/api/system/dict.js";
import setPostParams from "../../../utils/searchParams.js";
import{ useRoute } from 'vue-router'

const {proxy} = getCurrentInstance();
const route = ref(useRoute())
/**
 * 搜索相关
 */
/** 搜索按钮操作 */
function handleQuery() {
    getList({keywords: searchParams.value.deviceId})
}

/** 重置按钮操作 */
function resetQuery() {
    proxy.resetForm("queryRef");
    handleQuery();
}

/**
 *  Table表格权限数据列表相关
 */
const searchParam = {
    limit: 15,
    page: 1
}
const pageParam = ref({
    total: 0,
    limit: 0,
    page: 1,
})
const tableData = ref([]);
let tableHeader = ref({
    schemeName: '方案名称',
    facilityName: '设备名称',
    columnsCode: '参数编码',
    columnsShow: '参数名称',
    schemeTypeView: '方案类型',
    informTypeView: '通知方式',
    lowAlarm: '低报警值',
    lowsAlarm: '低低报警值',
    tallAlarm: '高报警值',
    tallsAlarm: '高高报警值',
    informUser: '通知人员',
    beginTime: '启用日期',
    periodTime: '有效日期',
    createTimeView: '创建日期'
})

async function getList(val) {
    loading.value = true;

 let postParam = setPostParams(val)
    await alarmSchemeApi().search(postParam).then((res) => {
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
    loading.value = false;
}

//查询设备列表
const facilityList = ref();
const informUserList = ref();
const parameterList = ref();
const informTypeList = ref();
const schemeTypeList=ref();


const getFacilityList = async () => {
    await facilityApi().search({limit: 10000, page: 1}).then((res) => {
        console.log("设备列表" + res.data.list);
        facilityList.value = res.data.list
    })
}
const getInformUserList = async () => {
    await user().search({limit: 10000, page: 1}).then((res) => {
        console.log("通知人员列表" + res.data.list);
        informUserList.value = res.data.list
    })
}
const getInformTypeList = async () => {
    let res= await sysDictData().searchType('inform_type')
        console.log("字典列表1" + res.data);
    if (res.code == 200) {
        informTypeList.value = res.data
    }
    let res1= await sysDictData().searchType('scheme_type')
    console.log("字典列表2" + res.data);
    if (res1.code == 200) {
        schemeTypeList.value = res1.data
    }
}
getInformTypeList()
const handleChange = async (val) => {
    form.columnsCode = "";
    //通过用户id获取该用户下的水表信息
    let res = await waterFacilityParameter().getParam(val)
    console.log("设备参数", res.data)
    if (res.code == 200) {
        parameterList.value = res.data
    }
}
getInformUserList()
getFacilityList()
/**
 *  表单相关
 */
const formLabel = ({
    deviceId: '报警设备',
    code: '警报代码',
    description: '描述'
})

const searchParams = ref({
    keywords: '',
});
/**
 *  新增/修改弹窗Form表单相关
 */
const open = ref(false);
const loading = ref(false);
const title = ref("");

const data = reactive({
    form: {},
    queryParams: {
        name: undefined,
    },
    rules: {
        schemeName: [{required: true, message: "请输入方案名称", trigger: "blur"}],
        facilityId: [{required: true, message: "请输入设备信息", trigger: "blur"}],
        columnsCode: [{required: true, message: "请输入参数信息", trigger: "blur"}],
        schemeType: [{required: true, message: "请输入方案类型", trigger: "blur"}],
        informType: [{required: true, message: "请输入通知方式", trigger: "blur"}],
        beginTime: [{required: true, message: "请输入启用时间", trigger: "blur"}],
        periodTime: [{required: true, message: "请输入有效时间", trigger: "blur"}],
        informUser: [{required: true, message: "请输入通人员", trigger: "blur"}],


    },
});
const {queryParams, form, rules} = toRefs(data);

/** 提交按钮 */
function submitForm() {
    proxy.$refs["formRef"].validate(valid => {
        if (valid) {
            if (form.value.id != undefined) {
                alarmSchemeApi().modify(form.value).then(res => {
                    proxy.$modal.msgSuccess("修改成功");
                    open.value = false;
                    getList();
                }).catch(() => {
                    open.value = false;
                    proxy.$modal.msgError("修改失败");
                });
            } else {
                alarmSchemeApi().create(form.value).then(res => {
                    proxy.$modal.msgSuccess("新增成功");
                    open.value = false;
                    getList();
                }).catch(() => {
                    open.value = false;
                    proxy.$modal.msgError("新增失败");
                });
                ;
            }
        }
    });
}

/** 新增按钮操作 */
async function handleAdd() {
    reset();
    open.value = true;
    title.value = "新增";
}

/** 修改按钮操作 */
async function handleUpdate(row) {
    reset();
    form.value = Object.assign({}, row)
    open.value = true;
    title.value = "修改报警参数";
}

/** 删除按钮操作 */
function handleDelete(row) {
    proxy.$modal.confirm('是否确认删除名称为"' + row.description + '"的数据项?').then(function () {
        return alarmSchemeApi().remove(row.id);
    }).then(() => {
        getList();
        proxy.$modal.msgSuccess("删除成功");
    }).catch(() => {
    });
}

/** 取消按钮 */
function cancel() {
    open.value = false;
    reset();
}

/** 表单重置 */
function reset() {
    form.value = {
        code: '',
        comment: '',
        description: undefined,
    };
    proxy.resetForm("formRef");
}

getList();
</script>
<template>
    <div class="app-container">
        <el-form :model="searchParams" ref="queryRef" :inline="true">
            <el-form-item label="" prop="">
                <el-input
                        v-model="searchParams.deviceId"
                        placeholder="请输入搜索信息"
                        clearable
                        style="width: 200px"
                        @keyup.enter="handleQuery"
                />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
                <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button
                        type="primary"
                        plain
                        icon="Plus"
                        @click="handleAdd"
                >新增
                </el-button>
            </el-col>
        </el-row>
        <!--表格及分页-->
        <el-table v-loading="loading" :data="tableData">
            <el-table-column
                    v-for="(item, key, index) of tableHeader"
                    :prop="key.toString()"
                    :label="item"
                    :key="index"
                    align="center"
            >
                <template #default="scope">
                    <div v-if="key.toString() == 'headImg'">
                        <img :src="scope.row.headImg" class="table-headImg"/>
                    </div>
                </template>
            </el-table-column>
            <el-table-column label="操作" width="180" align="center" class-deviceId="small-padding fixed-width">
                <template #default="scope">
                    <el-button link type="primary" icon="Edit" v-has="['update',route]"
                               @click="handleUpdate(scope.row)">修改
                    </el-button>
                    <el-button link type="primary" icon="Delete" v-has="['delete',route]"
                               @click="handleDelete(scope.row)">删除
                    </el-button>
                </template>
            </el-table-column>
        </el-table>
        <pagination
                :total="pageParam.total"
                v-model:page="pageParam.page"
                v-model:limit="pageParam.limit"
                :page-sizes="[10,20,30]"
                @pagination="getList"
        />
        <!-- 添加或修改对话框 -->
        <el-dialog :title="title" v-model="open" append-to-body center>
            <el-form class="form-box" ref="formRef" :model="form" :rules="rules" label-width='auto'>
                        <el-form-item label="选择设备" prop="facilityId">
                            <el-select v-model="form.facilityId" placeholder="请输入设备信息" @change="handleChange">
                                <el-option
                                        v-for="(item,index) in facilityList"
                                        :label="item.facilityName"
                                        :value="item.id"
                                        :key="index"
                                ></el-option>
                            </el-select>
                        </el-form-item>
                        <el-form-item label="选择设备参数" prop="columnsCode">
                            <el-select v-model="form.columnsCode" placeholder="请输入设备参数" >
                                <el-option
                                        v-for="(item,index) in parameterList"
                                        :label="item.columnsShow"
                                        :value="item.columnsCode"
                                        :key="index"
                                ></el-option>
                            </el-select>
                        </el-form-item>
                        <el-form-item label="报警方案名称" prop="schemeName">
                            <el-input v-model="form.schemeName" placeholder="请输入报警方案名称"/>
                        </el-form-item>
                        <el-form-item label="报警类型" prop="schemeType">
                            <el-select v-model="form.schemeType" placeholder="请选择报警类型" >
                                <el-option
                                    v-for="item in schemeTypeList"
                                    :key="item.id"
                                    :label="item.dictLabel"
                                    :title="item.dictValue"
                                    :value="item.dictValue"
                                />
                            </el-select>
                        </el-form-item>
                        <el-form-item label="通知方式" prop="informType">
                            <el-select v-model="form.informType" placeholder="请选择通知方式" >
                                <el-option
                                    v-for="item in informTypeList"
                                    :key="item.id"
                                    :label="item.dictLabel"
                                    :title="item.dictValue"
                                    :value="item.dictValue"
                                />
                            </el-select>
                        </el-form-item>
                        <el-form-item label="低报警值" prop="lowAlarm">
                            <el-input v-model="form.lowAlarm" placeholder="请输入低报警值"/>
                        </el-form-item>
                        <el-form-item label="低低报警值" prop="lowsAlarm">
                            <el-input v-model="form.lowsAlarm" placeholder="请输低低报警值"/>
                        </el-form-item>
                        <el-form-item label="高报警值" prop="tallAlarm">
                            <el-input v-model="form.tallAlarm" placeholder="请输入高报警值"/>
                        </el-form-item>
                        <el-form-item label="高高报警值" prop="tallsAlarm">
                            <el-input v-model="form.tallsAlarm" placeholder="请输入高高报警值"/>
                        </el-form-item>
                        <el-form-item label="通知人员" prop="informUser">
                            <el-select v-model="form.informUser" placeholder="请选择通知人员">
                                <el-option
                                        v-for="item in informUserList"
                                        :key="item.id"
                                        :label="item.nickName"
                                        :title="item.nickName"
                                        :value="item.nickName"
                                />
                            </el-select>
                        </el-form-item>
                        <el-form-item label="启用日期" prop="beginTime">
                            <el-date-picker
                                    v-model="form.beginTime"
                                    type="date"
                                    placeholder="请选择启用时间"
                                    format="YYYY-MM-DD"
                                    value-format="YYYY-MM-DD"
                                    :disabled="isDetail ? true : false"
                            />
                        </el-form-item>
                        <el-form-item label="有效日期" prop="periodTime">
                            <el-date-picker
                                    v-model="form.periodTime"
                                    type="date"
                                    placeholder="请选择启用时间"
                                    format="YYYY-MM-DD"
                                    value-format="YYYY-MM-DD"
                                    :disabled="isDetail ? true : false"
                            />
                        </el-form-item>
                        <el-form-item label="备注" prop="remark">
                            <el-input v-model="form.remark" placeholder="请输入备注"/>
                        </el-form-item>
                <el-form-item></el-form-item>

            </el-form>
            <template #footer>
                <div class="dialog-footer">
                    <el-button type="primary" @click="submitForm">确 定</el-button>
                    <el-button @click="cancel">取 消</el-button>
                </div>
            </template>
        </el-dialog>
    </div>
</template>

<style lang="scss" scoped>

</style>
 